@@ -311,7 +311,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             }
         }
 
-        final String site = Strings.join(HelperClass.decode(normalized.subList(2, normalized.size()), req,SPLIT2), "/");
+        final String site = Strings.join(HelperClass.decode(normalized.size() > 2 ? normalized.subList(2, normalized.size()) : normalized, req, SPLIT2), "/");
         final Map<String, String> args = new HashMap<String, String>();
         args.put(MODULE, normalized.get(0));
         args.put(CONTEXTID, normalized.get(1));
